@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
 use Moo;
 use strictures 2;
@@ -51,8 +51,6 @@ has filters => (
     default => sub { {} },
 );
 
-# Private attributes
-
 has _msg_channel => (
     is      => 'ro',
     default => sub { IO::Async::Channel->new },
@@ -174,7 +172,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
@@ -259,9 +257,9 @@ Return or set the B<filters>.
 
 =head2 new
 
-  $rtc = MIDI::RtController->new(verbose => 1);
+  $rtc = MIDI::RtController->new(%attributes);
 
-Create a new C<MIDI::RtController> object.
+Create a new C<MIDI::RtController> object given the above attributes.
 
 =for Pod::Coverage BUILD
 
@@ -281,7 +279,9 @@ C<pitch_wheel_change>, etc.).
 
   $rtc->send_it($event);
 
-Send a MIDI B<event> to the output port.
+Send a MIDI B<event> to the output port, where the MIDI event is an
+ARRAY reference like, C<['note_on', 0, 40, 107]> or
+C<['control_change', 0, 1, 24]>, etc.
 
 =head2 delay_send
 
